@@ -1,6 +1,7 @@
 parse_query <- function(query) {
   params <- vapply(strsplit(query, "&")[[1]], str_split_fixed, "=", 2,
-    FUN.VALUE = character(2))
+    FUN.VALUE = character(2)
+  )
 
   values <- as.list(curl::curl_unescape(params[2, ]))
   names(values) <- curl::curl_unescape(params[1, ])
@@ -8,11 +9,13 @@ parse_query <- function(query) {
 }
 
 compose_query <- function(elements) {
-  if (length(elements) == 0)
+  if (length(elements) == 0) {
     return("")
+  }
 
-  if (!all(has_name(elements)))
+  if (!all(has_name(elements))) {
     stop("All components of query must be named", call. = FALSE)
+  }
 
   stopifnot(is.list(elements))
   elements <- compact(elements)
